##  Best Practices
Use the advanced configuration of the ServiceNow integration for the following purposes:
  * Configure advanced settings: Configure settings that can not be configured otherwise and adjust settings for advanced use cases.
  * Back up and restore configurations: You can use the JSON code version control, backup, and restoration purposes. Simply copy the full JSON code and save it in a file for future use.
  * Restore the default configuration: To revert to the default configuration, remove the existing configuration in the JSON editor and input an empty JSON document {}. This action restores the default supported configuration mapping, providing a good starting point for your configuration.
